#[non_exhaustive]pub enum GlInitError {
DisplayBuild(String),
NoWindow,
WindowHandle(String),
ContextCreation(Error),
SurfaceAttributes(String),
SurfaceCreation(Error),
MakeCurrent(Error),
}Expand description
Errors that can occur during OpenGL / window initialization.
Each variant represents a distinct step in the initialization pipeline.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DisplayBuild(String)
The windowing / display builder failed to initialize.
NoWindow
The display builder succeeded but did not produce a window.
WindowHandle(String)
Failed to obtain the native window handle.
ContextCreation(Error)
OpenGL context creation failed. Wraps glutin::error::Error.
SurfaceAttributes(String)
Window surface attributes could not be constructed.
SurfaceCreation(Error)
Rendering surface creation failed. Wraps glutin::error::Error.
MakeCurrent(Error)
Making the GL context current on the surface failed. Wraps glutin::error::Error.