MjVfsError

Enum MjVfsError 

#[non_exhaustive]
pub enum MjVfsError { AlreadyExists, LoadFailed, NotFound, InvalidUtf8Path, BufferTooLarge, Unknown(i32), }
Errors that can occur in virtual file system (MjVfs) operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AlreadyExists

A file or mount with the same name already exists.



LoadFailed

MuJoCo failed to load the file or register the buffer.



NotFound

The specified file or directory was not found in the VFS.



InvalidUtf8Path

The provided path contains invalid UTF-8.



BufferTooLarge

The buffer length exceeds i32::MAX bytes.



Unknown(i32)

An unrecognized MuJoCo return code.