mjsCamera_

Struct mjsCamera_ 

pub struct mjsCamera_ { /* private fields */ }

Implementations

Source

impl mjsCamera_

pub fn info(&self) -> &str

Return the message appended to compiler errors.

Panics

Panics if it contains invalid UTF-8.

pub fn set_info(&mut self, info: &str)

Set the message appended to compiler errors.

Panics

When the info contains ‘\0’ characters, a panic occurs.

Source

impl mjsCamera_

pub fn pos(&self) -> &[f64; 3]

Return an immutable reference to camera position.

pub fn pos_mut(&mut self) -> &mut [f64; 3]

Return a mutable reference to camera position.

pub fn quat(&self) -> &[f64; 4]

Return an immutable reference to camera orientation.

pub fn quat_mut(&mut self) -> &mut [f64; 4]

Return a mutable reference to camera orientation.

pub fn alt(&self) -> &MjsOrientation

Return an immutable reference to alternative orientation.

pub fn alt_mut(&mut self) -> &mut MjsOrientation

Return a mutable reference to alternative orientation.

pub fn intrinsic(&self) -> &[f32; 4]

Return an immutable reference to intrinsic parameters.

pub fn intrinsic_mut(&mut self) -> &mut [f32; 4]

Return a mutable reference to intrinsic parameters.

pub fn sensor_size(&self) -> &[f32; 2]

Return an immutable reference to sensor size.

pub fn sensor_size_mut(&mut self) -> &mut [f32; 2]

Return a mutable reference to sensor size.

pub fn resolution(&self) -> &[i32; 2]

Return an immutable reference to resolution.

pub fn resolution_mut(&mut self) -> &mut [i32; 2]

Return a mutable reference to resolution.

pub fn focal_length(&self) -> &[f32; 2]

Return an immutable reference to focal length (length).

pub fn focal_length_mut(&mut self) -> &mut [f32; 2]

Return a mutable reference to focal length (length).

pub fn focal_pixel(&self) -> &[f32; 2]

Return an immutable reference to focal length (pixel).

pub fn focal_pixel_mut(&mut self) -> &mut [f32; 2]

Return a mutable reference to focal length (pixel).

pub fn principal_length(&self) -> &[f32; 2]

Return an immutable reference to principal point (length).

pub fn principal_length_mut(&mut self) -> &mut [f32; 2]

Return a mutable reference to principal point (length).

pub fn principal_pixel(&self) -> &[f32; 2]

Return an immutable reference to principal point (pixel).

pub fn principal_pixel_mut(&mut self) -> &mut [f32; 2]

Return a mutable reference to principal point (pixel).

pub fn with_pos(&mut self, value: [f64; 3]) -> &mut Self

Builder method for setting camera position.

pub fn with_quat(&mut self, value: [f64; 4]) -> &mut Self

Builder method for setting camera orientation.

pub fn with_alt(&mut self, value: MjsOrientation) -> &mut Self

Builder method for setting alternative orientation.

pub fn with_intrinsic(&mut self, value: [f32; 4]) -> &mut Self

Builder method for setting intrinsic parameters.

pub fn with_sensor_size(&mut self, value: [f32; 2]) -> &mut Self

Builder method for setting sensor size.

pub fn with_resolution(&mut self, value: [i32; 2]) -> &mut Self

Builder method for setting resolution.

pub fn with_focal_length(&mut self, value: [f32; 2]) -> &mut Self

Builder method for setting focal length (length).

pub fn with_focal_pixel(&mut self, value: [f32; 2]) -> &mut Self

Builder method for setting focal length (pixel).

pub fn with_principal_length(&mut self, value: [f32; 2]) -> &mut Self

Builder method for setting principal point (length).

pub fn with_principal_pixel(&mut self, value: [f32; 2]) -> &mut Self

Builder method for setting principal point (pixel).

pub fn mode(&self) -> MjtCamLight

Return value of camera mode.

pub fn fovy(&self) -> f64

Return value of field of view in y direction.

pub fn ipd(&self) -> f64

Return value of inter-pupillary distance for stereo.

pub fn proj(&self) -> MjtProjection

Return value of camera projection type.

pub fn output(&self) -> i32

Return value of bit flags for output type.

pub fn set_mode(&mut self, value: MjtCamLight)

Set camera mode.

pub fn set_fovy(&mut self, value: f64)

Set field of view in y direction.

pub fn set_ipd(&mut self, value: f64)

Set inter-pupillary distance for stereo.

pub fn set_proj(&mut self, value: MjtProjection)

Set camera projection type.

pub fn set_output(&mut self, value: i32)

Set bit flags for output type.

pub fn with_mode(&mut self, value: MjtCamLight) -> &mut Self

Builder method for setting camera mode.

pub fn with_fovy(&mut self, value: f64) -> &mut Self

Builder method for setting field of view in y direction.

pub fn with_ipd(&mut self, value: f64) -> &mut Self

Builder method for setting inter-pupillary distance for stereo.

pub fn with_proj(&mut self, value: MjtProjection) -> &mut Self

Builder method for setting camera projection type.

pub fn with_output(&mut self, value: i32) -> &mut Self

Builder method for setting bit flags for output type.

pub fn userdata(&self) -> &[f64]

Return an immutable slice to userdata.

pub fn set_userdata<T: AsRef<[f64]>>(&mut self, value: T)

Set userdata.

pub fn with_userdata<T: AsRef<[f64]>>(&mut self, value: T) -> &mut Self

Builder method for setting userdata.

pub fn targetbody(&self) -> &str

Return target body for tracking/targeting.

Panics

Panics if the stored string is not valid UTF-8, which can only happen on internal memory corruption – MuJoCo only uses ASCII values.

pub fn set_targetbody(&mut self, value: &str)

Set target body for tracking/targeting.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn with_targetbody(&mut self, value: &str) -> &mut Self

Builder method for setting target body for tracking/targeting.

Panics

When the value contains ‘\0’ characters, a panic occurs.