pub struct mjsExclude_ { /* private fields */ }Implementations
Sourceimpl mjsExclude_
impl mjsExclude_
Sourceimpl mjsExclude_
impl mjsExclude_
Sourcepub fn bodyname1(&self) -> &str
pub fn bodyname1(&self) -> &str
Return name of body 1.
Panics
Panics if the stored string is not valid UTF-8, which can only happen on internal memory corruption – MuJoCo only uses ASCII values.
Sourcepub fn set_bodyname1(&mut self, value: &str)
pub fn set_bodyname1(&mut self, value: &str)
Sourcepub fn with_bodyname1(&mut self, value: &str) -> &mut Self
pub fn with_bodyname1(&mut self, value: &str) -> &mut Self
Builder method for setting name of body 1.
Panics
When the value contains ‘\0’ characters, a panic occurs.
Sourcepub fn bodyname2(&self) -> &str
pub fn bodyname2(&self) -> &str
Return name of body 2.
Panics
Panics if the stored string is not valid UTF-8, which can only happen on internal memory corruption – MuJoCo only uses ASCII values.
Sourcepub fn set_bodyname2(&mut self, value: &str)
pub fn set_bodyname2(&mut self, value: &str)
Sourcepub fn with_bodyname2(&mut self, value: &str) -> &mut Self
pub fn with_bodyname2(&mut self, value: &str) -> &mut Self
Builder method for setting name of body 2.
Panics
When the value contains ‘\0’ characters, a panic occurs.