mjsSensor_

Struct mjsSensor_ 

pub struct mjsSensor_ { /* private fields */ }

Implementations

Source

impl mjsSensor_

pub fn info(&self) -> &str

Return the message appended to compiler errors.

Panics

Panics if it contains invalid UTF-8.

pub fn set_info(&mut self, info: &str)

Set the message appended to compiler errors.

Panics

When the info contains ‘\0’ characters, a panic occurs.

Source

impl mjsSensor_

pub fn intprm(&self) -> &[i32; 3]

Return an immutable reference to integer parameters.

pub fn intprm_mut(&mut self) -> &mut [i32; 3]

Return a mutable reference to integer parameters.

pub fn interval(&self) -> &[f64; 2]

Return an immutable reference to [period, time_prev] in seconds.

pub fn interval_mut(&mut self) -> &mut [f64; 2]

Return a mutable reference to [period, time_prev] in seconds.

pub fn with_intprm(&mut self, value: [i32; 3]) -> &mut Self

Builder method for setting integer parameters.

pub fn with_interval(&mut self, value: [f64; 2]) -> &mut Self

Builder method for setting [period, time_prev] in seconds.

pub fn plugin(&self) -> &MjsPlugin

Return an immutable reference to sensor plugin.

pub fn plugin_mut(&mut self) -> &mut MjsPlugin

Return a mutable reference to sensor plugin.

pub fn type_(&self) -> MjtSensor

Return value of sensor type.

pub fn objtype(&self) -> MjtObj

Return value of object type the sensor refers to.

pub fn reftype(&self) -> MjtObj

Return value of type of referenced object.

pub fn datatype(&self) -> MjtDataType

Return value of data type.

pub fn cutoff(&self) -> f64

Return value of cutoff for real and positive datatypes.

pub fn noise(&self) -> f64

Return value of noise stdev.

pub fn needstage(&self) -> MjtStage

Return value of compute stage needed to simulate sensor.

pub fn dim(&self) -> i32

Return value of number of scalar outputs.

pub fn nsample(&self) -> i32

Return value of number of samples in history buffer.

pub fn interp(&self) -> i32

Return value of interpolation order (0=ZOH, 1=linear, 2=cubic).

pub fn delay(&self) -> f64

Return value of delay time in seconds; 0: no delay.

pub fn set_type(&mut self, value: MjtSensor)

Set sensor type.

pub fn set_objtype(&mut self, value: MjtObj) -> Result<(), MjEditError>

Set object type the sensor refers to.

Errors

Returns MjEditError::InvalidParameter when the object type is not a real object type (i.e. not below MjtObj::mjNOBJECT).

pub fn set_reftype(&mut self, value: MjtObj) -> Result<(), MjEditError>

Set type of referenced object.

Errors

Returns MjEditError::InvalidParameter when the reference type is not a real object type (i.e. not below MjtObj::mjNOBJECT).

pub fn set_datatype(&mut self, value: MjtDataType)

Set data type.

pub fn set_cutoff(&mut self, value: f64)

Set cutoff for real and positive datatypes.

pub fn set_noise(&mut self, value: f64)

Set noise stdev.

pub fn set_needstage(&mut self, value: MjtStage)

Set compute stage needed to simulate sensor.

pub fn set_dim(&mut self, value: i32)

Set number of scalar outputs.

pub fn set_nsample(&mut self, value: i32)

Set number of samples in history buffer.

pub fn set_interp(&mut self, value: i32)

Set interpolation order (0=ZOH, 1=linear, 2=cubic).

pub fn set_delay(&mut self, value: f64)

Set delay time in seconds; 0: no delay.

pub fn with_type(&mut self, value: MjtSensor) -> &mut Self

Builder method for setting sensor type.

pub fn with_objtype(&mut self, value: MjtObj) -> &mut Self

Builder method for setting object type the sensor refers to.

Panics

Panics with MjEditError::InvalidParameter when the object type is not a real object type (i.e. not below MjtObj::mjNOBJECT).

pub fn with_reftype(&mut self, value: MjtObj) -> &mut Self

Builder method for setting type of referenced object.

Panics

Panics with MjEditError::InvalidParameter when the reference type is not a real object type (i.e. not below MjtObj::mjNOBJECT).

pub fn with_datatype(&mut self, value: MjtDataType) -> &mut Self

Builder method for setting data type.

pub fn with_cutoff(&mut self, value: f64) -> &mut Self

Builder method for setting cutoff for real and positive datatypes.

pub fn with_noise(&mut self, value: f64) -> &mut Self

Builder method for setting noise stdev.

pub fn with_needstage(&mut self, value: MjtStage) -> &mut Self

Builder method for setting compute stage needed to simulate sensor.

pub fn with_dim(&mut self, value: i32) -> &mut Self

Builder method for setting number of scalar outputs.

pub fn with_nsample(&mut self, value: i32) -> &mut Self

Builder method for setting number of samples in history buffer.

pub fn with_interp(&mut self, value: i32) -> &mut Self

Builder method for setting interpolation order (0=ZOH, 1=linear, 2=cubic).

pub fn with_delay(&mut self, value: f64) -> &mut Self

Builder method for setting delay time in seconds; 0: no delay.

pub fn userdata(&self) -> &[f64]

Return an immutable slice to userdata.

pub fn set_userdata<T: AsRef<[f64]>>(&mut self, value: T)

Set userdata.

pub fn with_userdata<T: AsRef<[f64]>>(&mut self, value: T) -> &mut Self

Builder method for setting userdata.

pub fn refname(&self) -> &str

Return name of referenced object.

Panics

Panics if the stored string is not valid UTF-8, which can only happen on internal memory corruption – MuJoCo only uses ASCII values.

pub fn set_refname(&mut self, value: &str)

Set name of referenced object.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn with_refname(&mut self, value: &str) -> &mut Self

Builder method for setting name of referenced object.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn objname(&self) -> &str

Return name of sensorized object.

Panics

Panics if the stored string is not valid UTF-8, which can only happen on internal memory corruption – MuJoCo only uses ASCII values.

pub fn set_objname(&mut self, value: &str)

Set name of sensorized object.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn with_objname(&mut self, value: &str) -> &mut Self

Builder method for setting name of sensorized object.

Panics

When the value contains ‘\0’ characters, a panic occurs.