mjsTexture_

Struct mjsTexture_ 

pub struct mjsTexture_ { /* private fields */ }

Implementations

Source

impl mjsTexture_

pub fn info(&self) -> &str

Return the message appended to compiler errors.

Panics

Panics if it contains invalid UTF-8.

pub fn set_info(&mut self, info: &str)

Set the message appended to compiler errors.

Panics

When the info contains ‘\0’ characters, a panic occurs.

Source

impl mjsTexture_

Note – cube-map files

The cubefiles field is a pre-sized string vector (6 entries, one per cube face). Use set_cubefile with a MjtCubeFace variant to assign a file to a specific face. The bulk set_cubefiles / append_cubefiles methods are also available but operate on the vector as a whole.

pub fn rgb1(&self) -> &[f64; 3]

Return an immutable reference to first color for builtin.

pub fn rgb1_mut(&mut self) -> &mut [f64; 3]

Return a mutable reference to first color for builtin.

pub fn rgb2(&self) -> &[f64; 3]

Return an immutable reference to second color for builtin.

pub fn rgb2_mut(&mut self) -> &mut [f64; 3]

Return a mutable reference to second color for builtin.

pub fn markrgb(&self) -> &[f64; 3]

Return an immutable reference to mark color.

pub fn markrgb_mut(&mut self) -> &mut [f64; 3]

Return a mutable reference to mark color.

pub fn gridsize(&self) -> &[i32; 2]

Return an immutable reference to size of grid for composite file; (1,1)-repeat.

pub fn gridsize_mut(&mut self) -> &mut [i32; 2]

Return a mutable reference to size of grid for composite file; (1,1)-repeat.

pub fn gridlayout(&self) -> &[c_char; 12]

Return an immutable reference to row-major: L,R,F,B,U,D for faces; . for unused.

pub fn gridlayout_mut(&mut self) -> &mut [c_char; 12]

Return a mutable reference to row-major: L,R,F,B,U,D for faces; . for unused.

pub fn with_rgb1(&mut self, value: [f64; 3]) -> &mut Self

Builder method for setting first color for builtin.

pub fn with_rgb2(&mut self, value: [f64; 3]) -> &mut Self

Builder method for setting second color for builtin.

pub fn with_markrgb(&mut self, value: [f64; 3]) -> &mut Self

Builder method for setting mark color.

pub fn with_gridsize(&mut self, value: [i32; 2]) -> &mut Self

Builder method for setting size of grid for composite file; (1,1)-repeat.

pub fn with_gridlayout(&mut self, value: [c_char; 12]) -> &mut Self

Builder method for setting row-major: L,R,F,B,U,D for faces; . for unused.

pub fn random(&self) -> f64

Return value of probability of random dots.

pub fn width(&self) -> i32

Return value of image width.

pub fn height(&self) -> i32

Return value of image height.

pub fn set_random(&mut self, value: f64)

Set probability of random dots.

pub fn set_width(&mut self, value: i32)

Set image width.

pub fn set_height(&mut self, value: i32)

Set image height.

pub fn with_random(&mut self, value: f64) -> &mut Self

Builder method for setting probability of random dots.

pub fn with_width(&mut self, value: i32) -> &mut Self

Builder method for setting image width.

pub fn with_height(&mut self, value: i32) -> &mut Self

Builder method for setting image height.

pub fn nchannel(&self) -> i32

Return value of number of channels.

pub fn set_nchannel(&mut self, value: i32)

Set number of channels.

pub fn with_nchannel(&mut self, value: i32) -> &mut Self

Builder method for setting number of channels.

pub fn type_(&self) -> MjtTexture

Return value of texture type.

pub fn colorspace(&self) -> MjtColorSpace

Return value of colorspace.

pub fn builtin(&self) -> MjtBuiltin

Return value of builtin type.

pub fn mark(&self) -> MjtMark

Return value of mark type.

pub fn set_type(&mut self, value: MjtTexture)

Set texture type.

pub fn set_colorspace(&mut self, value: MjtColorSpace)

Set colorspace.

pub fn set_builtin(&mut self, value: MjtBuiltin)

Set builtin type.

pub fn set_mark(&mut self, value: MjtMark)

Set mark type.

pub fn with_type(&mut self, value: MjtTexture) -> &mut Self

Builder method for setting texture type.

pub fn with_colorspace(&mut self, value: MjtColorSpace) -> &mut Self

Builder method for setting colorspace.

pub fn with_builtin(&mut self, value: MjtBuiltin) -> &mut Self

Builder method for setting builtin type.

pub fn with_mark(&mut self, value: MjtMark) -> &mut Self

Builder method for setting mark type.

pub fn set_cubefile(&mut self, role: MjtCubeFace, name: &str)

Sets the entry at index role in cubefiles to name. different file for each side of the cube.

The cubefiles vector is pre-sized by MuJoCo (one slot per MjtCubeFace variant); this method writes directly into the correct slot.

Panics

When name contains ‘\0’ characters, a panic occurs.

pub fn with_cubefile(&mut self, role: MjtCubeFace, name: &str) -> &mut Self

Sets the entry at index role in cubefiles to name, returning &mut Self for chaining. different file for each side of the cube.

Equivalent to set_cubefile.

pub fn set_cubefiles(&mut self, value: &str)

Replaces the entire cubefiles vector with whitespace-split entries from value. different file for each side of the cube.

This replaces the pre-sized vector. Prefer set_cubefile to set individual entries by role.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn append_cubefiles(&mut self, value: &str)

Appends value to the end of cubefiles. different file for each side of the cube.

Appending extends past the pre-sized vector. Prefer set_cubefile to set individual entries by role.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn hflip(&self) -> bool

Check horizontal flip.

pub fn vflip(&self) -> bool

Check vertical flip.

pub fn set_hflip(&mut self, value: bool)

Set horizontal flip.

pub fn set_vflip(&mut self, value: bool)

Set vertical flip.

pub fn with_hflip(&mut self, value: bool) -> &mut Self

Builder method for setting horizontal flip.

pub fn with_vflip(&mut self, value: bool) -> &mut Self

Builder method for setting vertical flip.

pub fn set_data<T: NoUninit>(&mut self, data: &[T])

Sets texture data.

pub fn file(&self) -> &str

Return png file to load; use for all sides of cube.

Panics

Panics if the stored string is not valid UTF-8, which can only happen on internal memory corruption – MuJoCo only uses ASCII values.

pub fn set_file(&mut self, value: &str)

Set png file to load; use for all sides of cube.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn with_file(&mut self, value: &str) -> &mut Self

Builder method for setting png file to load; use for all sides of cube.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn content_type(&self) -> &str

Return content type of file.

Panics

Panics if the stored string is not valid UTF-8, which can only happen on internal memory corruption – MuJoCo only uses ASCII values.

pub fn set_content_type(&mut self, value: &str)

Set content type of file.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn with_content_type(&mut self, value: &str) -> &mut Self

Builder method for setting content type of file.

Panics

When the value contains ‘\0’ characters, a panic occurs.