#[non_exhaustive]pub enum MjViewerError {
EventLoopError(EventLoopError),
GlutinError(Error),
PainterInitError(String),
GlInitFailed(GlInitError),
SceneError(MjSceneError),
ContextError(MjrContextError),
SignatureMismatch,
IndexOutOfBounds {
id: usize,
len: usize,
},
}Expand description
Errors that can occur when initializing or running the MuJoCo viewer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EventLoopError(EventLoopError)
The event loop failed to initialize.
GlutinError(Error)
A glutin operation failed.
PainterInitError(String)
Returned when the egui painter (OpenGL UI renderer) fails to initialize.
GlInitFailed(GlInitError)
OpenGL / window initialization failed.
SceneError(MjSceneError)
A scene operation failed (e.g. user-scene sync overflowed the geom buffer).
ContextError(MjrContextError)
A rendering-context operation failed (e.g. a pixel-read buffer is too small or the viewport has invalid dimensions).
SignatureMismatch
The model’s structure signature does not match the viewer’s passive model.
Call ViewerSharedState::sync_model or ViewerSharedState::sync_data first.
IndexOutOfBounds
The asset ID is out of range.