pub type MjtTimer = mjtTimer;Expand description
Timer types. The number of timer types is given by mjNTIMER which is also the length of the array
mjData.timer, as well as the length of the string array mjTIMERSTRING with timer names.
Aliased Type
#[repr(u32)]pub enum MjtTimer {
Show 16 variants
mjTIMER_STEP = 0,
mjTIMER_FORWARD = 1,
mjTIMER_INVERSE = 2,
mjTIMER_POSITION = 3,
mjTIMER_VELOCITY = 4,
mjTIMER_ACTUATION = 5,
mjTIMER_CONSTRAINT = 6,
mjTIMER_ADVANCE = 7,
mjTIMER_POS_KINEMATICS = 8,
mjTIMER_POS_INERTIA = 9,
mjTIMER_POS_COLLISION = 10,
mjTIMER_POS_MAKE = 11,
mjTIMER_POS_PROJECT = 12,
mjTIMER_COL_BROAD = 13,
mjTIMER_COL_NARROW = 14,
mjNTIMER = 15,
}