MjsCompiler

Struct MjsCompiler 

pub struct MjsCompiler { /* private fields */ }
Compiler options. An opaque handle for the FFI type mjsCompiler, reached through ffi.

Implementations

Source

impl MjsCompiler

pub fn ffi(&self) -> &mjsCompiler

Returns the FFI struct that the handle stands on.

pub unsafe fn ffi_mut(&mut self) -> &mut mjsCompiler

Returns the FFI struct that the handle stands on, mutably.

Safety

The caller must not exchange the contents of the struct with another element’s.

Source

impl MjsCompiler

pub fn autolimits(&self) -> bool

Check infer “limited” attribute based on range.

pub fn balanceinertia(&self) -> bool

Check automatically impose A + B >= C rule.

pub fn fitaabb(&self) -> bool

Check meshfit to aabb instead of inertia box.

pub fn degree(&self) -> bool

Check angles in radians or degrees.

pub fn discardvisual(&self) -> bool

Check discard visual geoms in parser.

pub fn usethread(&self) -> bool

Check use multiple threads to speed up compiler.

pub fn fusestatic(&self) -> bool

Check fuse static bodies with parent.

pub fn saveinertial(&self) -> bool

Check save explicit inertial clause for all bodies to XML.

pub fn alignfree(&self) -> bool

Check align free joints with inertial frame.

pub fn set_autolimits(&mut self, value: bool)

Set infer “limited” attribute based on range.

pub fn set_balanceinertia(&mut self, value: bool)

Set automatically impose A + B >= C rule.

pub fn set_fitaabb(&mut self, value: bool)

Set meshfit to aabb instead of inertia box.

pub fn set_degree(&mut self, value: bool)

Set angles in radians or degrees.

pub fn set_discardvisual(&mut self, value: bool)

Set discard visual geoms in parser.

pub fn set_usethread(&mut self, value: bool)

Set use multiple threads to speed up compiler.

pub fn set_fusestatic(&mut self, value: bool)

Set fuse static bodies with parent.

pub fn set_saveinertial(&mut self, value: bool)

Set save explicit inertial clause for all bodies to XML.

pub fn set_alignfree(&mut self, value: bool)

Set align free joints with inertial frame.

pub fn with_autolimits(&mut self, value: bool) -> &mut Self

Builder method for setting infer “limited” attribute based on range.

pub fn with_balanceinertia(&mut self, value: bool) -> &mut Self

Builder method for setting automatically impose A + B >= C rule.

pub fn with_fitaabb(&mut self, value: bool) -> &mut Self

Builder method for setting meshfit to aabb instead of inertia box.

pub fn with_degree(&mut self, value: bool) -> &mut Self

Builder method for setting angles in radians or degrees.

pub fn with_discardvisual(&mut self, value: bool) -> &mut Self

Builder method for setting discard visual geoms in parser.

pub fn with_usethread(&mut self, value: bool) -> &mut Self

Builder method for setting use multiple threads to speed up compiler.

pub fn with_fusestatic(&mut self, value: bool) -> &mut Self

Builder method for setting fuse static bodies with parent.

pub fn with_saveinertial(&mut self, value: bool) -> &mut Self

Builder method for setting save explicit inertial clause for all bodies to XML.

pub fn with_alignfree(&mut self, value: bool) -> &mut Self

Builder method for setting align free joints with inertial frame.

pub fn boundmass(&self) -> f64

Return value of enforce minimum body mass.

pub fn boundinertia(&self) -> f64

Return value of enforce minimum body diagonal inertia.

pub fn settotalmass(&self) -> f64

Return value of rescale masses and inertias; <=0: ignore.

pub fn set_boundmass(&mut self, value: f64)

Set enforce minimum body mass.

pub fn set_boundinertia(&mut self, value: f64)

Set enforce minimum body diagonal inertia.

pub fn set_settotalmass(&mut self, value: f64)

Set rescale masses and inertias; <=0: ignore.

pub fn with_boundmass(&mut self, value: f64) -> &mut Self

Builder method for setting enforce minimum body mass.

pub fn with_boundinertia(&mut self, value: f64) -> &mut Self

Builder method for setting enforce minimum body diagonal inertia.

pub fn with_settotalmass(&mut self, value: f64) -> &mut Self

Builder method for setting rescale masses and inertias; <=0: ignore.

pub fn inertiafromgeom(&self) -> MjtInertiaFromGeom

Return value of use geom inertias.

pub fn conflict(&self) -> MjtConflict

Return value of conflict-resolution policy for attach.

pub fn set_inertiafromgeom(&mut self, value: MjtInertiaFromGeom)

Set use geom inertias.

pub fn set_conflict(&mut self, value: MjtConflict)

Set conflict-resolution policy for attach.

pub fn with_inertiafromgeom(&mut self, value: MjtInertiaFromGeom) -> &mut Self

Builder method for setting use geom inertias.

pub fn with_conflict(&mut self, value: MjtConflict) -> &mut Self

Builder method for setting conflict-resolution policy for attach.

pub fn inertiagrouprange(&self) -> &[i32; 2]

Return an immutable reference to range of geom groups used to compute inertia.

pub fn inertiagrouprange_mut(&mut self) -> &mut [i32; 2]

Return a mutable reference to range of geom groups used to compute inertia.

pub fn eulerseq(&self) -> &[c_char; 3]

Return an immutable reference to sequence for euler rotations.

pub fn eulerseq_mut(&mut self) -> &mut [c_char; 3]

Return a mutable reference to sequence for euler rotations.

pub fn lropt(&self) -> &MjLROpt

Return an immutable reference to options for lengthrange computation.

pub fn lropt_mut(&mut self) -> &mut MjLROpt

Return a mutable reference to options for lengthrange computation.

pub fn with_inertiagrouprange(&mut self, value: [i32; 2]) -> &mut Self

Builder method for setting range of geom groups used to compute inertia.

pub fn with_eulerseq(&mut self, value: [c_char; 3]) -> &mut Self

Builder method for setting sequence for euler rotations.

pub fn with_lropt(&mut self, value: MjLROpt) -> &mut Self

Builder method for setting options for lengthrange computation.

pub fn meshdir(&self) -> &str

Return mesh and hfield directory.

Panics

Panics if the stored string is not valid UTF-8.

pub fn set_meshdir(&mut self, value: &str)

Set mesh and hfield directory.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn with_meshdir(&mut self, value: &str) -> &mut Self

Builder method for setting mesh and hfield directory.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn texturedir(&self) -> &str

Return texture directory.

Panics

Panics if the stored string is not valid UTF-8.

pub fn set_texturedir(&mut self, value: &str)

Set texture directory.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn with_texturedir(&mut self, value: &str) -> &mut Self

Builder method for setting texture directory.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn authored(&self) -> u64

Return value of bitmask of authored compiler fields.