MjsFrame

Struct MjsFrame 

pub struct MjsFrame { /* private fields */ }
MjsFrame specification. An opaque handle for the FFI type mjsFrame, reached through ffi.

Implementations

Source

impl MjsFrame

pub fn ffi(&self) -> &mjsFrame

Returns the FFI struct that the handle stands on.

pub unsafe fn ffi_mut(&mut self) -> &mut mjsFrame

Returns the FFI struct that the handle stands on, mutably.

Safety

The caller must not exchange the contents of the struct with another element’s.

Source

impl MjsFrame

pub fn info(&self) -> &str

Return the message appended to compiler errors.

Panics

Panics if it contains invalid UTF-8.

pub fn set_info(&mut self, info: &str)

Set the message appended to compiler errors.

Panics

When the info contains ‘\0’ characters, a panic occurs.

Source

impl MjsFrame

pub fn add_body(&mut self) -> &mut MjsBody

Add and return a child MjsBody.

Note

MuJoCo ends the process when the allocation fails.

pub fn try_add_body(&mut self) -> Result<&mut MjsBody, MjEditError>

👎Deprecated since 6.0.0:

always returns Ok; use the panicking variant

Fallible version of Self::add_body.

Note

mjs_addBody allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_body.

Errors

Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.

pub fn add_site(&mut self) -> &mut MjsSite

Add and return a child MjsSite.

Note

MuJoCo ends the process when the allocation fails.

pub fn try_add_site(&mut self) -> Result<&mut MjsSite, MjEditError>

👎Deprecated since 6.0.0:

always returns Ok; use the panicking variant

Fallible version of Self::add_site.

Note

mjs_addSite allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_site.

Errors

Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.

pub fn add_joint(&mut self) -> &mut MjsJoint

Add and return a child MjsJoint.

Note

MuJoCo ends the process when the allocation fails.

pub fn try_add_joint(&mut self) -> Result<&mut MjsJoint, MjEditError>

👎Deprecated since 6.0.0:

always returns Ok; use the panicking variant

Fallible version of Self::add_joint.

Note

mjs_addJoint allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_joint.

Errors

Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.

pub fn add_geom(&mut self) -> &mut MjsGeom

Add and return a child MjsGeom.

Note

MuJoCo ends the process when the allocation fails.

pub fn try_add_geom(&mut self) -> Result<&mut MjsGeom, MjEditError>

👎Deprecated since 6.0.0:

always returns Ok; use the panicking variant

Fallible version of Self::add_geom.

Note

mjs_addGeom allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_geom.

Errors

Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.

pub fn add_camera(&mut self) -> &mut MjsCamera

Add and return a child MjsCamera.

Note

MuJoCo ends the process when the allocation fails.

pub fn try_add_camera(&mut self) -> Result<&mut MjsCamera, MjEditError>

👎Deprecated since 6.0.0:

always returns Ok; use the panicking variant

Fallible version of Self::add_camera.

Note

mjs_addCamera allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_camera.

Errors

Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.

pub fn add_light(&mut self) -> &mut MjsLight

Add and return a child MjsLight.

Note

MuJoCo ends the process when the allocation fails.

pub fn try_add_light(&mut self) -> Result<&mut MjsLight, MjEditError>

👎Deprecated since 6.0.0:

always returns Ok; use the panicking variant

Fallible version of Self::add_light.

Note

mjs_addLight allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_light.

Errors

Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.

pub fn pos(&self) -> &[f64; 3]

Return an immutable reference to frame position.

pub fn pos_mut(&mut self) -> &mut [f64; 3]

Return a mutable reference to frame position.

pub fn quat(&self) -> &[f64; 4]

Return an immutable reference to frame orientation.

pub fn quat_mut(&mut self) -> &mut [f64; 4]

Return a mutable reference to frame orientation.

pub fn alt(&self) -> &MjsOrientation

Return an immutable reference to alternative orientation.

pub fn alt_mut(&mut self) -> &mut MjsOrientation

Return a mutable reference to alternative orientation.

pub fn with_pos(&mut self, value: [f64; 3]) -> &mut Self

Builder method for setting frame position.

pub fn with_quat(&mut self, value: [f64; 4]) -> &mut Self

Builder method for setting frame orientation.

pub fn with_alt(&mut self, value: MjsOrientation) -> &mut Self

Builder method for setting alternative orientation.

pub fn childclass(&self) -> &str

Return childclass name.

Panics

Panics if the stored string is not valid UTF-8.

pub fn set_childclass(&mut self, value: &str)

Set childclass name.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn with_childclass(&mut self, value: &str) -> &mut Self

Builder method for setting childclass name.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn add_frame(&mut self) -> &mut MjsFrame

Add and return a child frame.

Note

MuJoCo ends the process when the allocation fails.

pub fn try_add_frame(&mut self) -> Result<&mut MjsFrame, MjEditError>

👎Deprecated since 6.0.0:

always returns Ok; use add_frame

Fallible version of Self::add_frame.

Note

MuJoCo ends the process when the allocation fails, so this never returns Err.

Errors

Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the frame, instead of panicking.