MjsTuple

Struct MjsTuple 

pub struct MjsTuple { /* private fields */ }
MjsTuple specification. An opaque handle for the FFI type mjsTuple, reached through ffi.

Implementations

Source

impl MjsTuple

pub fn ffi(&self) -> &mjsTuple

Returns the FFI struct that the handle stands on.

pub unsafe fn ffi_mut(&mut self) -> &mut mjsTuple

Returns the FFI struct that the handle stands on, mutably.

Safety

The caller must not exchange the contents of the struct with another element’s.

Source

impl MjsTuple

pub fn info(&self) -> &str

Return the message appended to compiler errors.

Panics

Panics if it contains invalid UTF-8.

pub fn set_info(&mut self, info: &str)

Set the message appended to compiler errors.

Panics

When the info contains ‘\0’ characters, a panic occurs.

Source

impl MjsTuple

pub fn set_objtype(&mut self, value: &[MjtObj]) -> Result<(), MjEditError>

Set object types. Every value must be a real object type (an MjtObj below mjNOBJECT).

Errors

Returns MjEditError::InvalidParameter when any value is not a real object type (i.e. not below MjtObj::mjNOBJECT) (in that case nothing is written).

pub fn set_objname(&mut self, value: &str)

Splits the objname and put the split text as object names.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn append_objname(&mut self, value: &str)

Appends objname as a single entry to object names.

Panics

When the value contains ‘\0’ characters, a panic occurs.

pub fn objprm(&self) -> &[f64]

Return object parameters.

pub fn set_objprm(&mut self, value: &[f64])

Set object parameters.