#[non_exhaustive]pub enum MjModelError {
InvalidUtf8Path,
LoadFailed(String),
SaveFailed(String),
AllocationFailed,
StateSliceLengthMismatch {
expected: usize,
got: usize,
},
SpecNotSubset,
BufferTooSmall {
needed: usize,
available: usize,
},
SignatureMismatch {
source: u64,
destination: u64,
},
VfsError(MjVfsError),
InvalidIndex(usize, usize),
}Expand description
Errors that can occur in MjModel operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidUtf8Path
A filesystem path argument contains invalid UTF-8.
LoadFailed(String)
MuJoCo failed to load the model from a file, string, or buffer.
SaveFailed(String)
MuJoCo failed to save the model XML.
AllocationFailed
MuJoCo failed to allocate the requested structure.
StateSliceLengthMismatch
The state source slice has the wrong length for the given spec.
SpecNotSubset
The destination spec is not a subset of the source spec.
BufferTooSmall
A destination buffer is too small for the operation.
Fields
SignatureMismatch
Two model-signature-bound objects were created from different models.
Fields
VfsError(MjVfsError)
A virtual-file-system operation failed while loading a model from a string.
InvalidIndex(usize, usize)
The given index is invalid or out of range.