pub struct mjsFrame_ { /* private fields */ }Implementations
Sourceimpl mjsFrame_
impl mjsFrame_
Sourcepub fn add_body(&mut self) -> &mut MjsBody
pub fn add_body(&mut self) -> &mut MjsBody
Add and return a child MjsBody.
Delegates to Self::try_add_body and panics on failure.
Panics
Panics if MuJoCo fails to allocate the element.
Sourcepub fn try_add_body(&mut self) -> Result<&mut MjsBody, MjEditError>
pub fn try_add_body(&mut self) -> Result<&mut MjsBody, MjEditError>
Fallible version of Self::add_body.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn add_site(&mut self) -> &mut MjsSite
pub fn add_site(&mut self) -> &mut MjsSite
Add and return a child MjsSite.
Delegates to Self::try_add_site and panics on failure.
Panics
Panics if MuJoCo fails to allocate the element.
Sourcepub fn try_add_site(&mut self) -> Result<&mut MjsSite, MjEditError>
pub fn try_add_site(&mut self) -> Result<&mut MjsSite, MjEditError>
Fallible version of Self::add_site.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn add_joint(&mut self) -> &mut MjsJoint
pub fn add_joint(&mut self) -> &mut MjsJoint
Add and return a child MjsJoint.
Delegates to Self::try_add_joint and panics on failure.
Panics
Panics if MuJoCo fails to allocate the element.
Sourcepub fn try_add_joint(&mut self) -> Result<&mut MjsJoint, MjEditError>
pub fn try_add_joint(&mut self) -> Result<&mut MjsJoint, MjEditError>
Fallible version of Self::add_joint.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn add_geom(&mut self) -> &mut MjsGeom
pub fn add_geom(&mut self) -> &mut MjsGeom
Add and return a child MjsGeom.
Delegates to Self::try_add_geom and panics on failure.
Panics
Panics if MuJoCo fails to allocate the element.
Sourcepub fn try_add_geom(&mut self) -> Result<&mut MjsGeom, MjEditError>
pub fn try_add_geom(&mut self) -> Result<&mut MjsGeom, MjEditError>
Fallible version of Self::add_geom.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn add_camera(&mut self) -> &mut MjsCamera
pub fn add_camera(&mut self) -> &mut MjsCamera
Add and return a child MjsCamera.
Delegates to Self::try_add_camera and panics on failure.
Panics
Panics if MuJoCo fails to allocate the element.
Sourcepub fn try_add_camera(&mut self) -> Result<&mut MjsCamera, MjEditError>
pub fn try_add_camera(&mut self) -> Result<&mut MjsCamera, MjEditError>
Fallible version of Self::add_camera.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn add_light(&mut self) -> &mut MjsLight
pub fn add_light(&mut self) -> &mut MjsLight
Add and return a child MjsLight.
Delegates to Self::try_add_light and panics on failure.
Panics
Panics if MuJoCo fails to allocate the element.
Sourcepub fn try_add_light(&mut self) -> Result<&mut MjsLight, MjEditError>
pub fn try_add_light(&mut self) -> Result<&mut MjsLight, MjEditError>
Fallible version of Self::add_light.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn alt(&self) -> &MjsOrientation
pub fn alt(&self) -> &MjsOrientation
Return an immutable reference to alternative orientation.
Sourcepub fn alt_mut(&mut self) -> &mut MjsOrientation
pub fn alt_mut(&mut self) -> &mut MjsOrientation
Return a mutable reference to alternative orientation.
Sourcepub fn with_pos(&mut self, value: [f64; 3]) -> &mut Self
pub fn with_pos(&mut self, value: [f64; 3]) -> &mut Self
Builder method for setting frame position.
Sourcepub fn with_quat(&mut self, value: [f64; 4]) -> &mut Self
pub fn with_quat(&mut self, value: [f64; 4]) -> &mut Self
Builder method for setting frame orientation.
Sourcepub fn with_alt(&mut self, value: MjsOrientation) -> &mut Self
pub fn with_alt(&mut self, value: MjsOrientation) -> &mut Self
Builder method for setting alternative orientation.
Sourcepub fn childclass(&self) -> &str
pub fn childclass(&self) -> &str
Return childclass name.
Panics
Panics if the stored string is not valid UTF-8, which can only happen on internal memory corruption – MuJoCo only uses ASCII values.
Sourcepub fn set_childclass(&mut self, value: &str)
pub fn set_childclass(&mut self, value: &str)
Sourcepub fn with_childclass(&mut self, value: &str) -> &mut Self
pub fn with_childclass(&mut self, value: &str) -> &mut Self
Builder method for setting childclass name.
Panics
When the value contains ‘\0’ characters, a panic occurs.
Sourcepub fn add_frame(&mut self) -> &mut MjsFrame
pub fn add_frame(&mut self) -> &mut MjsFrame
Add and return a child frame.
Delegates to Self::try_add_frame and panics if allocation fails.
Panics
Panics if MuJoCo fails to allocate the frame.
Sourcepub fn try_add_frame(&mut self) -> Result<&mut MjsFrame, MjEditError>
pub fn try_add_frame(&mut self) -> Result<&mut MjsFrame, MjEditError>
Fallible version of Self::add_frame.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate
the frame, instead of panicking.