pub struct MjsFrame { /* private fields */ }Expand description
Implementations
Sourceimpl MjsFrame
impl MjsFrame
Sourcepub fn try_add_body(&mut self) -> Result<&mut MjsBody, MjEditError>
👎Deprecated since 6.0.0: always returns Ok; use the panicking variant
pub fn try_add_body(&mut self) -> Result<&mut MjsBody, MjEditError>
always returns Ok; use the panicking variant
Fallible version of Self::add_body.
Note
mjs_addBody allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_body.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn try_add_site(&mut self) -> Result<&mut MjsSite, MjEditError>
👎Deprecated since 6.0.0: always returns Ok; use the panicking variant
pub fn try_add_site(&mut self) -> Result<&mut MjsSite, MjEditError>
always returns Ok; use the panicking variant
Fallible version of Self::add_site.
Note
mjs_addSite allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_site.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn try_add_joint(&mut self) -> Result<&mut MjsJoint, MjEditError>
👎Deprecated since 6.0.0: always returns Ok; use the panicking variant
pub fn try_add_joint(&mut self) -> Result<&mut MjsJoint, MjEditError>
always returns Ok; use the panicking variant
Fallible version of Self::add_joint.
Note
mjs_addJoint allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_joint.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn try_add_geom(&mut self) -> Result<&mut MjsGeom, MjEditError>
👎Deprecated since 6.0.0: always returns Ok; use the panicking variant
pub fn try_add_geom(&mut self) -> Result<&mut MjsGeom, MjEditError>
always returns Ok; use the panicking variant
Fallible version of Self::add_geom.
Note
mjs_addGeom allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_geom.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn add_camera(&mut self) -> &mut MjsCamera
pub fn add_camera(&mut self) -> &mut MjsCamera
Sourcepub fn try_add_camera(&mut self) -> Result<&mut MjsCamera, MjEditError>
👎Deprecated since 6.0.0: always returns Ok; use the panicking variant
pub fn try_add_camera(&mut self) -> Result<&mut MjsCamera, MjEditError>
always returns Ok; use the panicking variant
Fallible version of Self::add_camera.
Note
mjs_addCamera allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_camera.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn try_add_light(&mut self) -> Result<&mut MjsLight, MjEditError>
👎Deprecated since 6.0.0: always returns Ok; use the panicking variant
pub fn try_add_light(&mut self) -> Result<&mut MjsLight, MjEditError>
always returns Ok; use the panicking variant
Fallible version of Self::add_light.
Note
mjs_addLight allocates with C++ new, which ends the process instead of returning null, so this never returns Err. Prefer Self::add_light.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate the element.
Sourcepub fn alt(&self) -> &MjsOrientation
pub fn alt(&self) -> &MjsOrientation
Return an immutable reference to alternative orientation.
Sourcepub fn alt_mut(&mut self) -> &mut MjsOrientation
pub fn alt_mut(&mut self) -> &mut MjsOrientation
Return a mutable reference to alternative orientation.
Sourcepub fn with_pos(&mut self, value: [f64; 3]) -> &mut Self
pub fn with_pos(&mut self, value: [f64; 3]) -> &mut Self
Builder method for setting frame position.
Sourcepub fn with_quat(&mut self, value: [f64; 4]) -> &mut Self
pub fn with_quat(&mut self, value: [f64; 4]) -> &mut Self
Builder method for setting frame orientation.
Sourcepub fn with_alt(&mut self, value: MjsOrientation) -> &mut Self
pub fn with_alt(&mut self, value: MjsOrientation) -> &mut Self
Builder method for setting alternative orientation.
Sourcepub fn childclass(&self) -> &str
pub fn childclass(&self) -> &str
Sourcepub fn set_childclass(&mut self, value: &str)
pub fn set_childclass(&mut self, value: &str)
Sourcepub fn with_childclass(&mut self, value: &str) -> &mut Self
pub fn with_childclass(&mut self, value: &str) -> &mut Self
Builder method for setting childclass name.
Panics
When the value contains ‘\0’ characters, a panic occurs.
Sourcepub fn try_add_frame(&mut self) -> Result<&mut MjsFrame, MjEditError>
👎Deprecated since 6.0.0: always returns Ok; use add_frame
pub fn try_add_frame(&mut self) -> Result<&mut MjsFrame, MjEditError>
always returns Ok; use add_frame
Fallible version of Self::add_frame.
Note
MuJoCo ends the process when the allocation fails, so this never returns Err.
Errors
Returns MjEditError::AllocationFailed when MuJoCo fails to allocate
the frame, instead of panicking.