pub struct MjsTexture { /* private fields */ }Expand description
MjsTexture specification. An opaque handle for the FFI type mjsTexture, reached through ffi.
Implementations
Sourceimpl MjsTexture
impl MjsTexture
Sourcepub fn ffi(&self) -> &mjsTexture
pub fn ffi(&self) -> &mjsTexture
Returns the FFI struct that the handle stands on.
Sourcepub unsafe fn ffi_mut(&mut self) -> &mut mjsTexture
pub unsafe fn ffi_mut(&mut self) -> &mut mjsTexture
Returns the FFI struct that the handle stands on, mutably.
Safety
The caller must not exchange the contents of the struct with another element’s.
Sourceimpl MjsTexture
impl MjsTexture
Sourceimpl MjsTexture
Note: cube-map files
cubefiles is a pre-sized string vector of 6 entries, one per cube face. Assign one face with
set_cubefile; set_cubefiles and
append_cubefiles replace or extend the vector as a whole.
impl MjsTexture
Note: cube-map files
cubefiles is a pre-sized string vector of 6 entries, one per cube face. Assign one face with
set_cubefile; set_cubefiles and
append_cubefiles replace or extend the vector as a whole.
Sourcepub fn rgb1_mut(&mut self) -> &mut [f64; 3]
pub fn rgb1_mut(&mut self) -> &mut [f64; 3]
Return a mutable reference to first color for builtin.
Sourcepub fn rgb2_mut(&mut self) -> &mut [f64; 3]
pub fn rgb2_mut(&mut self) -> &mut [f64; 3]
Return a mutable reference to second color for builtin.
Sourcepub fn markrgb_mut(&mut self) -> &mut [f64; 3]
pub fn markrgb_mut(&mut self) -> &mut [f64; 3]
Return a mutable reference to mark color.
Sourcepub fn gridsize(&self) -> &[i32; 2]
pub fn gridsize(&self) -> &[i32; 2]
Return an immutable reference to size of grid for composite file; (1,1)-repeat.
Sourcepub fn gridsize_mut(&mut self) -> &mut [i32; 2]
pub fn gridsize_mut(&mut self) -> &mut [i32; 2]
Return a mutable reference to size of grid for composite file; (1,1)-repeat.
Sourcepub fn gridlayout(&self) -> &[c_char; 12]
pub fn gridlayout(&self) -> &[c_char; 12]
Return an immutable reference to row-major: L,R,F,B,U,D for faces; . for unused.
Sourcepub fn gridlayout_mut(&mut self) -> &mut [c_char; 12]
pub fn gridlayout_mut(&mut self) -> &mut [c_char; 12]
Return a mutable reference to row-major: L,R,F,B,U,D for faces; . for unused.
Sourcepub fn with_rgb1(&mut self, value: [f64; 3]) -> &mut Self
pub fn with_rgb1(&mut self, value: [f64; 3]) -> &mut Self
Builder method for setting first color for builtin.
Sourcepub fn with_rgb2(&mut self, value: [f64; 3]) -> &mut Self
pub fn with_rgb2(&mut self, value: [f64; 3]) -> &mut Self
Builder method for setting second color for builtin.
Sourcepub fn with_markrgb(&mut self, value: [f64; 3]) -> &mut Self
pub fn with_markrgb(&mut self, value: [f64; 3]) -> &mut Self
Builder method for setting mark color.
Sourcepub fn with_gridsize(&mut self, value: [i32; 2]) -> &mut Self
pub fn with_gridsize(&mut self, value: [i32; 2]) -> &mut Self
Builder method for setting size of grid for composite file; (1,1)-repeat.
Sourcepub fn with_gridlayout(&mut self, value: [c_char; 12]) -> &mut Self
pub fn with_gridlayout(&mut self, value: [c_char; 12]) -> &mut Self
Builder method for setting row-major: L,R,F,B,U,D for faces; . for unused.
Sourcepub fn set_random(&mut self, value: f64)
pub fn set_random(&mut self, value: f64)
Set probability of random dots.
Sourcepub fn set_height(&mut self, value: i32)
pub fn set_height(&mut self, value: i32)
Set image height.
Sourcepub fn with_random(&mut self, value: f64) -> &mut Self
pub fn with_random(&mut self, value: f64) -> &mut Self
Builder method for setting probability of random dots.
Sourcepub fn with_width(&mut self, value: i32) -> &mut Self
pub fn with_width(&mut self, value: i32) -> &mut Self
Builder method for setting image width.
Sourcepub fn with_height(&mut self, value: i32) -> &mut Self
pub fn with_height(&mut self, value: i32) -> &mut Self
Builder method for setting image height.
Sourcepub fn set_nchannel(&mut self, value: i32)
pub fn set_nchannel(&mut self, value: i32)
Set number of channels.
Sourcepub fn with_nchannel(&mut self, value: i32) -> &mut Self
pub fn with_nchannel(&mut self, value: i32) -> &mut Self
Builder method for setting number of channels.
Sourcepub fn type_(&self) -> MjtTexture
pub fn type_(&self) -> MjtTexture
Return value of texture type.
Sourcepub fn colorspace(&self) -> MjtColorSpace
pub fn colorspace(&self) -> MjtColorSpace
Return value of colorspace.
Sourcepub fn builtin(&self) -> MjtBuiltin
pub fn builtin(&self) -> MjtBuiltin
Return value of builtin type.
Sourcepub fn set_type(&mut self, value: MjtTexture)
pub fn set_type(&mut self, value: MjtTexture)
Set texture type.
Sourcepub fn set_colorspace(&mut self, value: MjtColorSpace)
pub fn set_colorspace(&mut self, value: MjtColorSpace)
Set colorspace.
Sourcepub fn set_builtin(&mut self, value: MjtBuiltin)
pub fn set_builtin(&mut self, value: MjtBuiltin)
Set builtin type.
Sourcepub fn with_type(&mut self, value: MjtTexture) -> &mut Self
pub fn with_type(&mut self, value: MjtTexture) -> &mut Self
Builder method for setting texture type.
Sourcepub fn with_colorspace(&mut self, value: MjtColorSpace) -> &mut Self
pub fn with_colorspace(&mut self, value: MjtColorSpace) -> &mut Self
Builder method for setting colorspace.
Sourcepub fn with_builtin(&mut self, value: MjtBuiltin) -> &mut Self
pub fn with_builtin(&mut self, value: MjtBuiltin) -> &mut Self
Builder method for setting builtin type.
Sourcepub fn set_cubefile(&mut self, role: MjtCubeFace, name: &str)
pub fn set_cubefile(&mut self, role: MjtCubeFace, name: &str)
Sets the entry at index role in cubefiles to name. different file for each side of the cube.
Note
MuJoCo pre-sizes cubefiles with one slot per MjtCubeFace value. An index with no slot ends the process through mju_error.
Panics
When name contains ‘\0’ characters, a panic occurs.
Sourcepub fn with_cubefile(&mut self, role: MjtCubeFace, name: &str) -> &mut Self
pub fn with_cubefile(&mut self, role: MjtCubeFace, name: &str) -> &mut Self
Sets the entry at index role in cubefiles to name, returning &mut Self for chaining. different file for each side of the cube.
Equivalent to set_cubefile.
Panics
When name contains ‘\0’ characters, a panic occurs.
Sourcepub fn set_cubefiles(&mut self, value: &str)
pub fn set_cubefiles(&mut self, value: &str)
Replaces the entire cubefiles vector with whitespace-split entries from value. different file for each side of the cube.
This replaces the pre-sized vector. Prefer set_cubefile to set individual entries by role.
Panics
When the value contains ‘\0’ characters, a panic occurs.
Sourcepub fn append_cubefiles(&mut self, value: &str)
pub fn append_cubefiles(&mut self, value: &str)
Appends value to the end of cubefiles. different file for each side of the cube.
Appending extends past the pre-sized vector. Prefer set_cubefile to set individual entries by role.
Panics
When the value contains ‘\0’ characters, a panic occurs.
Sourcepub fn with_hflip(&mut self, value: bool) -> &mut Self
pub fn with_hflip(&mut self, value: bool) -> &mut Self
Builder method for setting horizontal flip.
Sourcepub fn with_vflip(&mut self, value: bool) -> &mut Self
pub fn with_vflip(&mut self, value: bool) -> &mut Self
Builder method for setting vertical flip.
Sourcepub fn file(&self) -> &str
pub fn file(&self) -> &str
Return png file to load; use for all sides of cube.
Panics
Panics if the stored string is not valid UTF-8.
Sourcepub fn set_file(&mut self, value: &str)
pub fn set_file(&mut self, value: &str)
Set png file to load; use for all sides of cube.
Panics
When the value contains ‘\0’ characters, a panic occurs.
Sourcepub fn with_file(&mut self, value: &str) -> &mut Self
pub fn with_file(&mut self, value: &str) -> &mut Self
Builder method for setting png file to load; use for all sides of cube.
Panics
When the value contains ‘\0’ characters, a panic occurs.
Sourcepub fn content_type(&self) -> &str
pub fn content_type(&self) -> &str
Sourcepub fn set_content_type(&mut self, value: &str)
pub fn set_content_type(&mut self, value: &str)
Sourcepub fn with_content_type(&mut self, value: &str) -> &mut Self
pub fn with_content_type(&mut self, value: &str) -> &mut Self
Builder method for setting content type of file.
Panics
When the value contains ‘\0’ characters, a panic occurs.