pub struct MjsTuple { /* private fields */ }Expand description
Implementations
Sourceimpl MjsTuple
impl MjsTuple
Sourcepub fn set_objtype(&mut self, value: &[MjtObj]) -> Result<(), MjEditError>
pub fn set_objtype(&mut self, value: &[MjtObj]) -> Result<(), MjEditError>
Set object types. Every value must be a real object type (an MjtObj below mjNOBJECT).
Errors
Returns MjEditError::InvalidParameter when any value is not a real object type (i.e. not below MjtObj::mjNOBJECT) (in that case nothing is written).
Sourcepub fn set_objname(&mut self, value: &str)
pub fn set_objname(&mut self, value: &str)
Splits the objname and put the split text as object names.
Panics
When the value contains ‘\0’ characters, a panic occurs.
Sourcepub fn append_objname(&mut self, value: &str)
pub fn append_objname(&mut self, value: &str)
Appends objname as a single entry to object names.
Panics
When the value contains ‘\0’ characters, a panic occurs.
Sourcepub fn set_objprm(&mut self, value: &[f64])
pub fn set_objprm(&mut self, value: &[f64])
Set object parameters.